@@ -12,7 +12,15 @@ use Audio::Nama::Assign qw(yaml_out);
 
 our (
 
-	$g,  # routing graph object
+	$g,  # routing graph object - 
+
+		# based on project data 
+		# the routing graph is generated,
+		# then traversed over, and integrated
+		# with track data to generate
+		# Audio::Nama::IO objects. Audio::Nama::IO objects are iterated
+		# over to generate 
+		# the Ecasound chain setup text (c.f. chains command)
 
 	@io, # IO objects corresponding to chain setup
 
@@ -48,6 +56,7 @@ sub initialize {
 	Audio::Nama::Graph::initialize_logger();
 	delete $setup->{latency_graph};
 	delete $setup->{final_graph};
+	$setup->{audio_length} = 0;  
 	@io = (); 			# IO object list
 	Audio::Nama::IO::initialize();
 	$g = Graph->new(); 	
@@ -83,7 +92,8 @@ sub engine_wav_out_tracks {
 }
 # return file output entries, including Mixdown 
 sub really_recording { 
-	map{ /-o:(.+?\.wav)$/} grep{ /-o:/ and /\.wav$/} split "\n", $chain_setup
+	my @files = map{ /-o:(.+?\.wav)$/} grep{ /-o:/ and /\.wav$/} split "\n", $chain_setup;
+	wantarray() ? @files : scalar @files;
 }
 	
 sub show_io {
@@ -94,20 +104,16 @@ sub show_io {
 sub generate_setup_try {  # TODO: move operations below to buses
 	logsub("&generate_setup_try");
 
+	my $extra_setup_code = shift;
+
 	# in an ideal CS world, all of the following routing
 	# routines (add_paths_for_*) would be accomplished by
-	# the track or bus itself, rather than the Hand of God, as
-	# appears below.
-	#
-	# On the other hand (or Hand!), one can't complain if
-	# the Hand of God happens to be doing exactly the
-	# right things. :-)
-
-	my $automix = shift; # route Master to null_out if present
+	# the track or bus itself, rather than handcoded below.
 	
 	# start with bus routing
 	
 	map{ $_->apply($g) } Audio::Nama::Bus::all();
+
 	$logger->debug("Graph after bus routing:\n$g");
 	
 	# now various manual routing
@@ -115,17 +121,16 @@ sub generate_setup_try {  # TODO: move operations below to buses
 	add_paths_for_aux_sends();
 	$logger->debug("Graph after aux sends:\n$g");
 
-	add_paths_from_Master(); # do they affect automix?
+	add_paths_from_Master();
 	$logger->debug("Graph with paths from Master:\n$g");
 
-	# re-route Master to null for automix
-	if( $automix){
-		$g->delete_edges(map{@$_} $g->edges_from('Master')); 
-		$g->add_edge(qw[Master null_out]);
-		$logger->debug("Graph with automix mods:\n$g");
-	}
 	add_paths_for_mixdown_handling();
 	$logger->debug("Graph with mixdown mods:\n$g");
+	
+	# run extra setup
+	
+	$extra_setup_code->($g) if $extra_setup_code;
+
 	prune_graph();
 	$setup->{latency_graph} = dclone($g);
 	$logger->debug("Graph after pruning unterminated branches:\n$g");
@@ -415,7 +420,7 @@ sub write_chains {
 
 	## write general options
 	
-	my $globals = $config->{engine_globals_general};
+	my $globals = $config->{engine_globals_common};
 	$globals .=  setup_requires_realtime()
 			? join " ", " -b:$config->{engine_buffersize_realtime}", 
 				$config->{engine_globals_realtime}
@@ -462,7 +467,7 @@ sub setup_requires_realtime {
 		or grep { has_vertex("$_\_out") } @fields
 
 }
-sub has_vertex { $setup->{final_graph}->has_vertex($_[0]) }
+sub has_vertex { $g->has_vertex($_[0]) }
 
 sub set_buffersize { 
 	my $buffer_type = setup_requires_realtime() ? "realtime" : "nonrealtime";
