@@ -12,10 +12,12 @@ sub setup_user_customization {
 		say "couldn't parse $filename: $@\n" if $@;
 		return;
 	}
-	logit(__LINE__,'Audio::Nama::Custom','debug','customization :', sub{yaml_out(\%custom)});
+	logpkg(__FILE__,__LINE__,'debug','customization :', sub{yaml_out(\%custom)});
 	my $prompt;
 	$prompt = gen_coderef('prompt', $custom{prompt}) if $custom{prompt};
-	*prompt = $prompt if $prompt;
+	{ no warnings 'redefine';
+		*prompt = $prompt if $prompt;
+	}
 	my @commands = keys %{ $custom{commands} };
 	for my $cmd(@commands){
 		my $coderef = gen_coderef($cmd,$custom{commands}{$cmd}) or next;
@@ -28,8 +30,7 @@ sub setup_user_customization {
 				$fx_cache->{partial_label_to_full}->{$_} = $longform
 			}
 		 else 
-			{ logit(__LINE__,'Audio::Nama::Custom','info',
-				"$longform: effect not found, cannot create shortcut") 
+			{ throw("$longform: effect not found, cannot create shortcut") 
 			}
  	} keys %{$custom{fxshortcuts}};
 }
