@@ -1,39 +1,79 @@
 # ------ Effect Routines -------
 
-package Audio::Nama;
+package Audio::Nama::Effects; # share namespace with Nama.pm and several others
 use Modern::Perl;
 use List::MoreUtils qw(insert_after_string);
+use Audio::Nama::Assign qw(yaml_out json_out);
 no warnings 'uninitialized';
-use Carp qw(cluck);
+use Carp;
+use Audio::Nama::Log qw(logsub logpkg);
+use Audio::Nama::Globals qw(
+					$fx 
+					$fx_cache 
+					$ui 
+					%ti 
+					%tn 
+					%bn 
+					$config 
+					$setup 
+					$this_op 
+					$this_track);
 
-# access routines
-# the lvalue routines can be on the left side of an assignment
-
-sub is_controller { 
-	my $id = shift; 
-	catch_null_id($id);
-	$fx->{applied}->{$id}->{belongs_to} 
+sub import_engine_subs {
 
+	*valid_engine_setup = \&Audio::Nama::valid_engine_setup;
+	*engine_running		= \&Audio::Nama::engine_running;
+	*eval_iam			= \&Audio::Nama::eval_iam;
+	*ecasound_select_chain = \&Audio::Nama::ecasound_select_chain;
+	*sleeper			= \&Audio::Nama::sleeper;
+	*process_command    = \&Audio::Nama::process_command;
 }
-sub has_read_only_param {
-	my $id = shift;
-	catch_null_id($id);
-	my $entry = $fx_cache->{registry}->[fxindex($id)];
-	logit(__LINE__,'Audio::Nama::Effects','logcluck',"undefined or unregistered effect id: $id"), 
-		return unless $id and $entry;
-		for(0..scalar @{$entry->{params}} - 1)
-		{
-			return 1 if $entry->{params}->[$_]->{dir} eq 'output' 
-		}
-}
-sub is_read_only {
-    my ($id, $param) = @_;
-	catch_null_id($id);
-    my $entry = $fx_cache->{registry}->[fxindex($id)];
-	logit(__LINE__,'Audio::Nama::Effects','logcluck',"undefined or unregistered effect id: $id"), 
-		return unless $id and $entry;
-	$entry->{params}->[$param]->{dir} eq 'output'
-}          
+
+use Exporter qw(import);
+our %EXPORT_TAGS = ( 'all' => [ qw(
+
+					parent
+					chain
+					type
+					bypassed
+					owns
+					fx
+					params
+					is_controller
+					
+					fxindex
+					effect_index
+					ecasound_effect_index
+					full_effect_code
+					name
+
+					catch_null_id
+					effect_entry_is_bad
+					check_fx_consistency
+
+					effect_init
+					add_effect
+					remove_effect
+					modify_effect
+					modify_multiple_effects
+
+					effect_update
+					effect_update_copp_set
+					sync_effect_parameters
+					find_op_offsets
+					apply_ops
+					expanded_ops_list
+				
+					is_read_only
+					bypass_effects
+			
+					restore_effects
+
+) ] );
+
+our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
+
+our @EXPORT = ();
 
 sub parent : lvalue { 
 	my $id = shift; 
@@ -50,18 +90,19 @@ sub type   : lvalue {
 	catch_null_id($id);
 	$fx->{applied}->{$id}->{type}       
 }
-sub bypassed: lvalue{ 
+sub bypassed : lvalue{ 
 	my $id = shift; 
 	catch_null_id($id);
 	$fx->{applied}->{$id}->{bypassed}   
 }
 
-# ensure owns field is initialized as anonymous array
+# ensure owns field is initialized as anonymous array 
+# bah!!
 
 sub owns   : lvalue { 
 	my $id = shift; 
 	catch_null_id($id);
-	$fx->{applied}->{$id}->{owns} ||= [] 
+	$fx->{applied}->{$id}->{owns}
 } 
 sub fx     : lvalue { 
 	my $id = shift; 
@@ -87,9 +128,42 @@ sub name {
 }
  
 sub catch_null_id {
+	return 0;
 	my $id = shift;
-	logit(__LINE__,'Audio::Nama::Effects','logconfess',"null effect id") unless $id;
+	logpkg(__FILE__,__LINE__,'logconfess',"null effect id")  unless $id;
+	logpkg(__FILE__,__LINE__,'debug',"$id: effect id does not exist") 
+		unless $fx->{applied}->{$id} and $fx-{params}->{$id}
 }
+sub effect_entry_is_bad {
+		my $id = shift;
+		! $id  									# undef key ''
+		or ! $fx->{params}->{$id}				# missing params entry 
+		or ! ref $fx->{applied}->{$id} 			# applied entry is not ref 
+		or keys %{$fx->{applied}->{$id}} < 3	# not enough key/val pairs
+}
+
+# access routines
+# the lvalue routines can be on the left side of an assignment
+
+sub is_controller 	{ my $id = shift; parent($id) }
+sub has_read_only_param {
+	my $op_id = shift;
+	my $entry = $fx_cache->{registry}->[fxindex($op_id)];
+	logpkg(__FILE__,__LINE__,'logcluck',"undefined or unregistered effect id: $op_id"), 
+		return unless $op_id and $entry;
+		for(0..scalar @{$entry->{params}} - 1)
+		{
+			return 1 if $entry->{params}->[$_]->{dir} eq 'output' 
+		}
+}
+sub is_read_only {
+    my ($op_id, $param) = @_;
+    my $entry = $fx_cache->{registry}->[fxindex($op_id)];
+	logpkg(__FILE__,__LINE__,'logcluck',"undefined or unregistered effect id: $op_id"), 
+		return unless $op_id and $entry;
+	$entry->{params}->[$param]->{dir} eq 'output'
+}          
+
 # make sure the chain number (track index) is set
 
 sub set_chain_value {
@@ -118,7 +192,7 @@ sub set_chain_value {
 	{
 		$p->{chain} = chain($p->{before});
 	}
-	#logit(__LINE__,'Audio::Nama::Effects','debug',(yaml_out($p));
+	#logpkg(__FILE__,__LINE__,'debug',(yaml_out($p));
 
 }
 
@@ -126,11 +200,26 @@ sub set_chain_value {
 sub add_effect {
 	my $p = shift;
 	logsub("&add_effect");
-	#logit(__LINE__,'Audio::Nama::Effects','debug',sub{ "add effect arguments - 0:\n".yaml_out($p)});
+	#logpkg(__FILE__,__LINE__,'debug',sub{ "add effect arguments - 0:\n".yaml_out($p)});
 	
 	set_chain_value($p);
 
-	logit(__LINE__,'Audio::Nama::Effects','debug',sub{ "add effect arguments - 1:\n".yaml_out($p)});
+	### We prohibit creating effects on the Mixdown track	
+
+	### We check $track->forbid_user_ops
+	### which is set on the Mixdown track,
+
+	### An alternative would be giving each
+    ### Track its own add_effect method
+
+	### For now this is a single case
+
+	die "user effects forbidden on this track" 
+		if $ti{$p->{chain}} 
+		and $ti{$p->{chain}}->forbid_user_ops 
+		and $p->{type} !~ /$config->{latency_op}/; 
+
+	logpkg(__FILE__,__LINE__,'debug',sub{ "add effect arguments - 1:\n".yaml_out($p)});
 
 	# either insert or add, depending on 'before' setting
 	
@@ -144,11 +233,15 @@ sub add_effect {
 sub _add_effect { 
 	my $p = shift;
 	my (    $n,   $before, $code,$parent_id,$id, $values) =
-	@$p{qw( chain before    type parent_id  cop_id values)};
+	@$p{qw( chain before    type parent_id  effect_id values)};
 	! $p->{chain} and
 		carp("effect id: $code is missing track number, skipping\n"), return ;
 
-	$id = cop_add($p); 
+	$p->{values} = fx_defaults($code) 
+		if ! $values 
+		or ref $values and ! scalar @{ $values };
+
+	$id = effect_init($p); 
 	
 	$ui->add_effect_gui($p) unless $ti{$n}->hide;
 	if( valid_engine_setup() )
@@ -156,7 +249,7 @@ sub _add_effect {
 		if (engine_running())
 		{ 
 			$ti{$n}->mute;
-			stop_do_start( sub{ apply_op($id) }, 0.05);
+			Audio::Nama::stop_do_start( sub{ apply_op($id) }, 0.05);
 			$ti{$n}->unmute;
 		}
 		else { apply_op($id) }
@@ -178,8 +271,8 @@ sub _insert_effect {  # call only from add_effect
 
 	if ($running){
 		$ui->stop_heartbeat;
-		mute();
-		eval_iam('stop-sync');
+		Audio::Nama::mute();
+		Audio::Nama::stop_command();
 		sleeper( 0.05); 
 	}
 	my $n = chain($before) or 
@@ -187,8 +280,8 @@ sub _insert_effect {  # call only from add_effect
 		return;
 	
 	my $track = $ti{$n};
-	#logit(__LINE__,'Audio::Nama::Effects','debug', $track->name, $/;
-	#logit(__LINE__,'Audio::Nama::Effects','debug', "@{$track->ops}")
+	#logpkg(__FILE__,__LINE__,'debug', $track->name, $/;
+	#logpkg(__FILE__,__LINE__,'debug', "@{$track->ops}")
 
 	# find offset 
 	
@@ -201,7 +294,7 @@ sub _insert_effect {  # call only from add_effect
 	# remove ops after insertion point if engine is connected
 
 	my @ops = @{$track->ops}[$offset..$#{$track->ops}];
-	logit(__LINE__,'Audio::Nama::Effects','debug',"ops to remove and re-apply: @ops");
+	logpkg(__FILE__,__LINE__,'debug',"ops to remove and re-apply: @ops");
 	my $connected = eval_iam('cs-connected');
 	if ( $connected ){  
 		map{ remove_op($_)} reverse @ops; # reverse order for correct index
@@ -209,7 +302,7 @@ sub _insert_effect {  # call only from add_effect
 
 	_add_effect($p);
 
-	logit(__LINE__,'Audio::Nama::Effects','debug',"@{$track->ops}");
+	logpkg(__FILE__,__LINE__,'debug',"@{$track->ops}");
 
 	# the new op_id is added to the end of the $track->ops list
 	# so we need to move it to specified insertion point
@@ -222,7 +315,7 @@ sub _insert_effect {  # call only from add_effect
 	# insert the effect id 
 	splice 	@{$track->ops}, $offset, 0, $op;
 
-	logit(__LINE__,'Audio::Nama::Effects','debug',sub{"@{$track->ops}"});
+	logpkg(__FILE__,__LINE__,'debug',sub{"@{$track->ops}"});
 
 	# replace the ops that had been removed
 	if ($connected ){  
@@ -232,14 +325,16 @@ sub _insert_effect {  # call only from add_effect
 	if ($running){
 		eval_iam('start');	
 		sleeper(0.3);
-		unmute();
+		Audio::Nama::unmute();
 		$ui->start_heartbeat;
 	}
 	$op
 }
 sub modify_effect {
 	my ($op_id, $parameter, $sign, $value) = @_;
-		# $parameter: zero based
+		# $parameter: one-based
+	
+	$parameter--; # convert to zero-based
 	my $cop = fx($op_id)
 		or print("$op_id: non-existing effect id. Skipping.\n"), return; 
 	my $code = type($op_id);
@@ -253,7 +348,7 @@ sub modify_effect {
 		unless ($parameter >= 0 and $parameter < $parameter_count);
 	print("$op_id: parameter $parameter is read-only, skipping\n"), return 
 		if is_read_only($op_id, $parameter);
-		my $new_value = $value; 
+		my $new_value = $value; # unless $sign
 		if ($sign) {
 			$new_value = 
  			eval (join " ",
@@ -262,10 +357,10 @@ sub modify_effect {
  				$value);
 		};
 	$this_op = $op_id;
-	logit(__LINE__,'Audio::Nama::Effects','debug', "id $op_id p: $parameter, sign: $sign value: $value");
+	logpkg(__FILE__,__LINE__,'debug', "id $op_id p: $parameter, sign: $sign value: $value");
 	effect_update_copp_set( 
 		$op_id, 
-		$parameter, 
+		$parameter,
 		$new_value);
 	1
 }
@@ -273,7 +368,6 @@ sub modify_multiple_effects {
 	my ($op_ids, $parameters, $sign, $value) = @_;
 	map{ my $op_id = $_;
 		map{ 	my $parameter = $_;
-				$parameter--; # convert to zero-base
 				modify_effect($op_id, $parameter, $sign, $value);
 		} @$parameters;
 		$this_op = $op_id; # set current effect
@@ -283,22 +377,23 @@ sub modify_multiple_effects {
 sub remove_effect { 
 	logsub("&remove_effect");
 	my $id = shift;
-	if( ! fx($id) ){
-		logit(__LINE__,'Audio::Nama::Effects','logcarp',"$id: does not exist, skipping...\n");
+	if( ! $id or ! fx($id) ){
+		logpkg(__FILE__,__LINE__,'logcarp',"$id: does not exist, skipping...\n");
 		return;
 	}
 	my $n 		= chain($id);
+	$n or die Audio::Nama::json_out(fx($id));
 	my $parent 	= parent($id);
 	my $owns	= owns($id);
-	logit(__LINE__,'Audio::Nama::Effects','debug', "id: $id, parent: $parent");
+	logpkg(__FILE__,__LINE__,'debug', "id: $id, parent: $parent");
 
 	my $object = $parent ? q(controller) : q(chain operator); 
-	logit(__LINE__,'Audio::Nama::Effects','debug', qq(ready to remove $object "$id" from track "$n"));
+	logpkg(__FILE__,__LINE__,'debug', qq(ready to remove $object "$id" from track "$n"));
 
 	$ui->remove_effect_gui($id);
 
 	# recursively remove children
-	logit(__LINE__,'Audio::Nama::Effects','debug',"children found: ". join ",",@$owns) if defined $owns;
+	logpkg(__FILE__,__LINE__,'debug',"children found: ". join ",",@$owns) if defined $owns;
 	map{ remove_effect($_) } @$owns if defined $owns;
 ;
 
@@ -315,15 +410,16 @@ sub remove_effect {
 		# remove parent ownership of deleted controller
 
 		my $parent_owns = owns($parent);
-		logit(__LINE__,'Audio::Nama::Effects','debug',"parent $parent owns: ". join ",", @$parent_owns);
+		logpkg(__FILE__,__LINE__,'debug',"parent $parent owns: ". join ",", @$parent_owns);
 
 		@$parent_owns = (grep {$_ ne $id} @$parent_owns);
-		logit(__LINE__,'Audio::Nama::Effects','debug',"parent $parent new owns list: ". join ",", @$parent_owns);
+		logpkg(__FILE__,__LINE__,'debug',"parent $parent new owns list: ". join ",", @$parent_owns);
 
 	}
-	$ti{$n}->remove_effect_from_track( $id ); 
-	delete $fx->{applied}->{$id}; # remove entry from chain operator list
-	delete $fx->{params }->{$id}; # remove entry from chain operator parameters list
+	$ti{$n}->remove_effect_from_track( $id ) if $ti{$n};
+	# remove entries for chain operator attributes and parameters
+ 	delete $fx->{applied}->{$id}; # remove entry from chain operator list
+    delete $fx->{params }->{$id}; # remove entry from chain operator parameters likk
 	$this_op = undef;
 }
 
@@ -362,7 +458,7 @@ sub position_effect {
 	$setup->{changed}++;
 	reconfigure_engine();
 	$this_track = $track;
-	command_process('show_track');
+	process_command('show_track');
 }
 
 ## array indices for Nama and Ecasound effects and controllers
@@ -372,8 +468,8 @@ sub nama_effect_index { # returns nama chain operator index
 	my $id = shift;
 	my $n = chain($id);
 	my $arr = $ti{$n}->ops;
-	logit(__LINE__,'Audio::Nama::Effects','debug', "id: $id n: $n");
-	logit(__LINE__,'Audio::Nama::Effects','debug', "@{$ti{$n}->ops}" );
+	logpkg(__FILE__,__LINE__,'debug', "id: $id n: $n");
+	logpkg(__FILE__,__LINE__,'debug', "@{$ti{$n}->ops}" );
 		for my $pos ( 0.. scalar @{ $ti{$n}->ops } - 1  ) {
 			return $pos if $arr->[$pos] eq $id; 
 		};
@@ -382,7 +478,7 @@ sub ecasound_effect_index {
 	my $id = shift;
 	my $n = chain($id);
 	my $opcount;  # one-based
-	logit(__LINE__,'Audio::Nama::Effects','debug', "id: $id, n: $n, ops: @{ $ti{$n}->ops }" );
+	logpkg(__FILE__,__LINE__,'debug', "id: $id, n: $n, ops: @{ $ti{$n}->ops }" );
 	for my $op (@{ $ti{$n}->ops }) { 
 			# increment only for ops, not controllers
 			next if is_controller($op);
@@ -472,13 +568,24 @@ sub effect_index {
 	$i
 }
 
+sub fx_defaults {
+	my $i = effect_index(shift());
+	my $values = [];
+	foreach my $p ( @{ $fx_cache->{registry}->[$i]->{params} })
+	{
+		return [] unless defined $p->{default};
+		push @$values, $p->{default};
+	}
+}
+	
+
 ## Ecasound engine -- apply/remove chain operators
 
 sub apply_ops {  # in addition to operators in .ecs file
 	
 	logsub("&apply_ops");
 	for my $n ( map{ $_->n } Audio::Nama::Track::all() ) {
-	logit(__LINE__,'Audio::Nama::Effects','debug', "chain: $n, offset: $fx->{offset}->{$n}");
+	logpkg(__FILE__,__LINE__,'debug', "chain: $n, offset: $fx->{offset}->{$n}");
  		next unless Audio::Nama::ChainSetup::is_ecasound_chain($n);
 
 	# controllers will follow ops, so safe to apply all in order
@@ -493,17 +600,19 @@ sub apply_op {
 	logsub("&apply_op");
 	local $config->{category} = 'ECI_FX';
 	my ($id, $selected_chain) = @_;
-	logit(__LINE__,'Audio::Nama::Effects','debug', "id: $id");
+	logpkg(__FILE__,__LINE__,'debug', "id: $id");
+	logpkg(__FILE__,__LINE__,'logcluck', "$id: expected effect entry not found!"), return
+		if effect_entry_is_bad($id);
 	my $code = type($id);
 	my $dad = parent($id);
 	my $chain = chain($id);
-	logit(__LINE__,'Audio::Nama::Effects','debug', "chain: ".chain($id)." type: $code");
+	logpkg(__FILE__,__LINE__,'debug', "chain: ".chain($id)." type: $code");
 	#  if code contains colon, then follow with comma (preset, LADSPA)
 	#  if code contains no colon, then follow with colon (ecasound,  ctrl)
 	
 	$code = '-' . $code . ($code =~ /:/ ? q(,) : q(:) );
 	my @vals = @{ params($id) };
-	logit(__LINE__,'Audio::Nama::Effects','debug', "values: @vals");
+	logpkg(__FILE__,__LINE__,'debug', "values: @vals");
 
 	# we start to build iam command
 
@@ -514,16 +623,17 @@ sub apply_op {
 	# append the -kx  operator for a controller-controller
 	$add_cmd .= " -kx" if $dad and is_controller($dad);
 
-	logit(__LINE__,'Audio::Nama::Effects','debug', "command: $add_cmd");
+	logpkg(__FILE__,__LINE__,'debug', "command: $add_cmd");
 
 	eval_iam("c-select $chain") if $selected_chain != $chain;
 	eval_iam("cop-select " . ecasound_effect_index($dad)) if $dad;
 	eval_iam($add_cmd);
+	eval_iam("cop-bypass on") if bypassed($id);
 
 	my $ref = ref owns($id) ;
 	$ref =~ /ARRAY/ or croak "expected array";
 	my @owns = @{ owns($id) }; 
-	logit(__LINE__,'Audio::Nama::Effects','debug',"children found: ". join ",", @{owns($id)});
+	logpkg(__FILE__,__LINE__,'debug',"children found: ". join ",", @{owns($id)});
 
 }
 sub remove_op {
@@ -547,29 +657,29 @@ sub remove_op {
 	my $index;
 
 	if ( ! is_controller($id) ){ # chain operator
-		logit(__LINE__,'Audio::Nama::Effects','debug', "no parent, assuming chain operator");
+		logpkg(__FILE__,__LINE__,'debug', "no parent, assuming chain operator");
 	
 		$index = ecasound_effect_index( $id );
-		logit(__LINE__,'Audio::Nama::Effects','debug', "ops list for chain $n: @{$ti{$n}->ops}");
-		logit(__LINE__,'Audio::Nama::Effects','debug', "operator id to remove: $id");
-		logit(__LINE__,'Audio::Nama::Effects','debug', "ready to remove from chain $n, operator id $id, index $index");
-		logit(__LINE__,'Audio::Nama::Effects','debug',sub{eval_iam("cs")});
+		logpkg(__FILE__,__LINE__,'debug', "ops list for chain $n: @{$ti{$n}->ops}");
+		logpkg(__FILE__,__LINE__,'debug', "operator id to remove: $id");
+		logpkg(__FILE__,__LINE__,'debug', "ready to remove from chain $n, operator id $id, index $index");
+		logpkg(__FILE__,__LINE__,'debug',sub{eval_iam("cs")});
 		eval_iam("cop-select ". ecasound_effect_index($id) );
-		logit(__LINE__,'Audio::Nama::Effects','debug',sub{"selected operator: ". eval_iam("cop-selected")});
+		logpkg(__FILE__,__LINE__,'debug',sub{"selected operator: ". eval_iam("cop-selected")});
 		eval_iam("cop-remove");
-		logit(__LINE__,'Audio::Nama::Effects','debug',sub{eval_iam("cs")});
+		logpkg(__FILE__,__LINE__,'debug',sub{eval_iam("cs")});
 
 	} else { # controller
 
-		logit(__LINE__,'Audio::Nama::Effects','debug', "has parent, assuming controller");
+		logpkg(__FILE__,__LINE__,'debug', "has parent, assuming controller");
 
 		my $ctrl_index = ctrl_index($id);
-		logit(__LINE__,'Audio::Nama::Effects','debug', eval_iam("cs"));
+		logpkg(__FILE__,__LINE__,'debug', eval_iam("cs"));
 		eval_iam("cop-select ".  ecasound_effect_index(root_parent($id)));
-		logit(__LINE__,'Audio::Nama::Effects','debug', "selected operator: ". eval_iam("cop-selected"));
+		logpkg(__FILE__,__LINE__,'debug', "selected operator: ". eval_iam("cop-selected"));
 		eval_iam("ctrl-select $ctrl_index");
 		eval_iam("ctrl-remove");
-		logit(__LINE__,'Audio::Nama::Effects','debug', eval_iam("cs"));
+		logpkg(__FILE__,__LINE__,'debug', eval_iam("cs"));
 	}
 }
 
@@ -597,30 +707,54 @@ sub root_parent {
 	parent($parent) || $parent
 }
 
-## Nama effects are represented by entries in $fx->{applied}
-## and by the ops array in each track, $track->ops
+## Nama effects 
 
-sub cop_add {
-	logsub("&cop_add");
+## have a unique ID from capital letters
+## are represented by entries in $fx->{applied}, $fx->{params}
+## IDs are kept in the $track->ops
+
+## Rules for allocating IDs
+## new_effect_id() - issues a new ID
+## effect_init()    - initializes a Nama effect, should be called effect_init()
+## add_effect
+
+sub new_effect_id { 
+
+		# increment $fx->{id_counter} if necessary
+		# to find an unused effect_id to allocate
+		
+		while( fx( $fx->{id_counter} )){ $fx->{id_counter}++};
+		$fx->{id_counter}
+}
+
+
+sub effect_init {
+	logsub("&effect_init");
 	my $p = shift;
-	logit(__LINE__,'Audio::Nama::Effects','debug',sub{yaml_out($p)});
+	logpkg(__FILE__,__LINE__,'debug',sub{yaml_out($p)});
 
 	my ($n,  $type, $id, $parent_id)  = 
 	@$p{qw( 
-	    chain type cop_id parent_id)};
+	    chain type effect_id parent_id)};
 
 	# return existing op_id if effect already exists
 	# unless effect chain asks us to get a new id
 	#
-	logit(__LINE__,'Audio::Nama::Effects','debug',"$id: returning existing id") if $id and fx($id);
+	logpkg(__FILE__,__LINE__,'debug',"$id: returning existing id") if $id and fx($id);
 	return $id if $id and fx($id);
-	
-	$id = $p->{cop_id} = $fx->{id_counter}  ;
-	logit(__LINE__,'Audio::Nama::Effects','debug',"$id: cop id issued");
+
+	my 	$allocated = "recycled";
+	if ( ! $id ){ 
+
+		$id = $p->{effect_id} = new_effect_id();
+		$allocated = "issued";
+	}
+
+	logpkg(__FILE__,__LINE__,'debug',"$id: effect id $allocated");
 
 	my $i = effect_index($type);
 
-	logit(__LINE__,'Audio::Nama::Effects','debug',"Issuing a cop_id for track $n: $id");
+	logpkg(__FILE__,__LINE__,'debug',"Issuing a effect_id for track $n: $id");
 	
 	# make entry in $fx->{applied} with chain, code, display-type, children
 
@@ -636,7 +770,7 @@ sub cop_add {
 	
 	if (! $parent_id and ! $p->{values}){
 		my @vals;
-		logit(__LINE__,'Audio::Nama::Effects','debug', "no settings found, loading defaults if present");
+		logpkg(__FILE__,__LINE__,'debug', "no settings found, loading defaults if present");
 		
 		# if the effect is a controller (has a parent), we don't 
 		# initialize the first parameter (the control target)
@@ -645,24 +779,24 @@ sub cop_add {
 		
 			push @vals, $fx_cache->{registry}->[$i]->{params}->[$j]->{default};
 		}
-		logit(__LINE__,'Audio::Nama::Effects','debug', "copid: $id defaults: @vals");
+		logpkg(__FILE__,__LINE__,'debug', "copid: $id defaults: @vals");
 		$p->{values} = \@vals;
 	}
 	
 	params($id) = $p->{values};
 
 	if ($parent_id) {
-		logit(__LINE__,'Audio::Nama::Effects','debug', "parent found: $parent_id");
+		logpkg(__FILE__,__LINE__,'debug', "parent found: $parent_id");
 
 		# store relationship
 
 		push @{ owns($parent_id) }, $id;
-		logit(__LINE__,'Audio::Nama::Effects','debug',"parent owns @{owns($parent_id)}");
+		logpkg(__FILE__,__LINE__,'debug',"parent owns @{owns($parent_id)}");
 
-		logit(__LINE__,'Audio::Nama::Effects','debug',sub{join " ", "my attributes:", yaml_out(fx($id))});
+		logpkg(__FILE__,__LINE__,'debug',sub{join " ", "my attributes:", yaml_out(fx($id))});
 		parent($id) = $parent_id;
-		logit(__LINE__,'Audio::Nama::Effects','debug',sub{join " ", "my attributes again:", yaml_out(fx($id))});
-		#logit(__LINE__,'Audio::Nama::Effects','debug', "parameter: $parameter");
+		logpkg(__FILE__,__LINE__,'debug',sub{join " ", "my attributes again:", yaml_out(fx($id))});
+		#logpkg(__FILE__,__LINE__,'debug', "parameter: $parameter");
 
 		# set fx-param to the parameter number, which one
 		# above the zero-based array offset that $parameter represents
@@ -686,10 +820,6 @@ sub cop_add {
 	else { push @{$ti{$n}->ops }, $id; } 
 
 
-	# make sure the counter $fx->{id_counter} will not occupy an
-	# already used value
-	while( fx( $fx->{id_counter} )){$fx->{id_counter}++};
-
 	$id;
 }
 
@@ -706,7 +836,7 @@ sub effect_update {
 
 	return unless valid_engine_setup();
 	#my $es = eval_iam("engine-status");
-	#logit(__LINE__,'Audio::Nama::Effects','debug', "engine is $es");
+	#logpkg(__FILE__,__LINE__,'debug', "engine is $es");
 	#return if $es !~ /not started|stopped|running/;
 
 	my ($id, $param, $val) = @_;
@@ -715,7 +845,7 @@ sub effect_update {
 	my $chain = chain($id);
 	return unless Audio::Nama::ChainSetup::is_ecasound_chain($chain);
 
-	logit(__LINE__,'Audio::Nama::Effects','debug', "chain $chain id $id param $param value $val");
+	logpkg(__FILE__,__LINE__,'debug', "chain $chain id $id param $param value $val");
 
 	# $param is zero-based. 
 	# %{$fx->{params}} is  zero-based.
@@ -726,14 +856,14 @@ sub effect_update {
 	# update Ecasound's copy of the parameter
 	if( is_controller($id)){
 		my $i = ecasound_controller_index($id);
-		logit(__LINE__,'Audio::Nama::Effects','debug', "controller $id: track: $chain, index: $i param: $param, value: $val");
+		logpkg(__FILE__,__LINE__,'debug', "controller $id: track: $chain, index: $i param: $param, value: $val");
 		eval_iam("ctrl-select $i");
 		eval_iam("ctrlp-select $param");
 		eval_iam("ctrlp-set $val");
 	}
 	else { # is operator
 		my $i = ecasound_operator_index($id);
-		logit(__LINE__,'Audio::Nama::Effects','debug', "operator $id: track $chain, index: $i, offset: ".
+		logpkg(__FILE__,__LINE__,'debug', "operator $id: track $chain, index: $i, offset: ".
 		$fx->{offset}->{$chain}. " param $param, value $val");
 		eval_iam("cop-select ". ($fx->{offset}->{$chain} + $i));
 		eval_iam("copp-select $param");
@@ -753,6 +883,7 @@ sub effect_update_copp_set {
 }
 
 sub sync_effect_parameters {
+	return; ### DIAGNOSTIC FOR TROUBLESHOOTING XXX
 	local $config->{category} = 'ECI_FX';
 	# when a controller changes an effect parameter
 	# the effect state can differ from the state in
@@ -805,7 +936,7 @@ sub find_op_offsets {
 	local $config->{category} = 'ECI_FX';
 	logsub("&find_op_offsets");
 	my @op_offsets = grep{ /"\d+"/} split "\n",eval_iam("cs");
-	logit(__LINE__,'Audio::Nama::Effects','debug', join "\n\n",@op_offsets);
+	logpkg(__FILE__,__LINE__,'debug', join "\n\n",@op_offsets);
 	for my $output (@op_offsets){
 		my $chain_id;
 		($chain_id) = $output =~ m/Chain "(\w*\d+)"/;
@@ -813,12 +944,13 @@ sub find_op_offsets {
 		next if $chain_id =~ m/\D/; # skip id's containing non-digits
 									# i.e. M1
 		my $quotes = $output =~ tr/"//;
-		logit(__LINE__,'Audio::Nama::Effects','debug', "offset: $quotes in $output");
+		logpkg(__FILE__,__LINE__,'debug', "offset: $quotes in $output");
 		$fx->{offset}->{$chain_id} = $quotes/2 - 1;  
 	}
 }
 
 sub expanded_ops_list { # including controllers
+						# we assume existing ops
 	my @ops_list = @_;
 	return () unless @_;
 	my @expanded = ();
@@ -876,97 +1008,6 @@ sub ops_data {
 }
 
 
-sub automix {
-
-	# get working track set
-	
-	my @tracks = grep{
-					$tn{$_}->rec_status eq 'MON' or
-					$bn{$_} and $tn{$_}->rec_status eq 'REC'
-				 } $bn{Main}->tracks;
-
-	say "tracks: @tracks";
-
-	## we do not allow automix if inserts are present	
-
-	say("Cannot perform automix if inserts are present. Skipping."), return
-		if grep{$tn{$_}->prefader_insert || $tn{$_}->postfader_insert} @tracks;
-
-	#use Smart::Comments '###';
-	# add -ev to summed signal
-	my $ev = add_effect( { chain => $tn{Master}->n, type => 'ev' } );
-	### ev id: $ev
-
-	# turn off audio output
-	
-	$tn{Master}->set(rw => 'OFF');
-
-	### Status before mixdown:
-
-	command_process('show');
-
-	
-	### reduce track volume levels  to 10%
-
-	## accommodate ea and eadb volume controls
-
-	my $vol_operator = type($tn{$tracks[0]}->vol);
-
-	my $reduce_vol_command  = $vol_operator eq 'ea' ? 'vol / 10' : 'vol - 10';
-	my $restore_vol_command = $vol_operator eq 'ea' ? 'vol * 10' : 'vol + 10';
-
-	### reduce vol command: $reduce_vol_command
-
-	for (@tracks){ command_process("$_  $reduce_vol_command") }
-
-	command_process('show');
-
-	generate_setup('automix') # pass a bit of magic
-		or say("automix: generate_setup failed!"), return;
-	connect_transport();
-	
-	# start_transport() does a rec_cleanup() on transport stop
-	
-	eval_iam('start'); # don't use heartbeat
-	sleep 2; # time for engine to stabilize
-	while( eval_iam('engine-status') ne 'finished'){ 
-		print q(.); sleep 1; update_clock_display()}; 
-	print " Done\n";
-
-	# parse cop status
-	my $cs = eval_iam('cop-status');
-	### cs: $cs
-	my $cs_re = qr/Chain "1".+?result-max-multiplier ([\.\d]+)/s;
-	my ($multiplier) = $cs =~ /$cs_re/;
-
-	### multiplier: $multiplier
-
-	remove_effect($ev);
-
-	# deal with all silence case, where multiplier is 0.00000
-	
-	if ( $multiplier < 0.00001 ){
-
-		say "Signal appears to be silence. Skipping.";
-		for (@tracks){ command_process("$_  $restore_vol_command") }
-		$tn{Master}->set(rw => 'MON');
-		return;
-	}
-
-	### apply multiplier to individual tracks
-
-	for (@tracks){ command_process( "$_ vol*$multiplier" ) }
-
-	### mixdown
-	command_process('mixdown; arm; start');
-
-	### turn on audio output
-
-	# command_process('mixplay'); # rec_cleanup does this automatically
-
-	#no Smart::Comments;
-	
-}
 
 sub bypass_effects {
 	my($track, @ops) = @_;
