@@ -9,7 +9,9 @@ no warnings qw(uninitialized);
 our @ISA;
 use vars qw($n %by_index);
 use Audio::Nama::Globals qw(:singletons %tn @fade_data); 
-use Audio::Nama::Log qw(logit);
+use Audio::Nama::Log qw(logsub logpkg);
+use Audio::Nama::Effects qw(remove_effect add_effect owns effect_update_copp_set);
+# we don't import 'type' as it would clobber our $fade->type attribute
 use Audio::Nama::Object qw( 
 				 n
 				 type
@@ -54,7 +56,7 @@ sub new {
 
 	$by_index{$object->n} = $object;
 
-	logit(__LINE__,'Audio::Nama::Fade','debug',"object class: $class, object type: ", ref $object);
+	logpkg(__FILE__,__LINE__,'debug',"object class: $class, object type: ", ref $object);
 
 	my $id = add_fader($object->track);	# only when necessary
 	
@@ -71,14 +73,17 @@ sub new {
 
 sub refresh_fade_controller {
 	my $track = shift;
-	my $operator  = $fx->{applied}->{$track->fader}->{type};
+	my $operator  = Audio::Nama::type($track->fader);
 	my $off_level = $config->{mute_level}->{$operator};
 	my $on_level  = $config->{unity_level}->{$operator};
-	my $controller; # effect ID
-	($controller) = @{$fx->{applied}->{$track->fader}{owns}} if $track->fader;
-
-	logit(__LINE__,'Audio::Nama::Fade','debug',"removing fade controller");
-	Audio::Nama::remove_effect($controller) if $controller;
+	my $controller;
+	($controller) = @{owns($track->fader)} if $track->fader;
+	if( $controller )
+	{
+		logpkg(__FILE__,__LINE__,'debug',$track->name, ": existing controller: $controller");
+		logpkg(__FILE__,__LINE__,'debug',"removing fade controller");
+		remove_effect($controller);
+	}
 
 	return unless
 		my @pairs = fader_envelope_pairs($track); 
@@ -88,9 +93,11 @@ sub refresh_fade_controller {
 	add_fader($track->name);	
 
 	# add controller
-	logit(__LINE__,'Audio::Nama::Fade','debug',"applying fade controller");
-	Audio::Nama::add_effect({
-		cop_id		=> $controller,
+	logpkg(__FILE__,__LINE__,'debug',"applying fade controller");
+
+	# we try to re-use the controller ID
+	add_effect({
+		effect_id		=> $controller,
 		parent_id 	=> $track->fader,
 		type		=> 'klg',	  		 # Ecasound controller
 		values		=> [	1,				 # Ecasound parameter 1
@@ -105,7 +112,7 @@ sub refresh_fade_controller {
 	# 	first fade is type 'out' : 100%
 	
 	 
-	Audio::Nama::effect_update_copp_set($track->fader,0, initial_level($track->name))
+	effect_update_copp_set($track->fader,0, initial_level($track->name))
 }
 
 
@@ -216,17 +223,17 @@ sub fader_envelope_pairs {
 				$marktime1 -= $fade->duration
 			} 
 		else { $fade->dumpp; die "fade processing failed" }
-		logit(__LINE__,'Audio::Nama::Fade','debug',"marktime1: $marktime1, marktime2: $marktime2");
+		logpkg(__FILE__,__LINE__,'debug',"marktime1: $marktime1, marktime2: $marktime2");
 		push @specs, 
 		[ 	$marktime1, 
 			$marktime2, 
 			$fade->type, 
-			$fx->{applied}->{$track->fader}->{type},
+			Audio::Nama::type($track->fader),
 		];
 }
 	# sort fades -  may not need this
 	@specs = sort{ $a->[0] <=> $b->[0] } @specs;
-	logit(__LINE__,'Audio::Nama::Fade','debug',sub{Audio::Nama::yaml_out( \@specs)});
+	logpkg(__FILE__,__LINE__,'debug',sub{Audio::Nama::yaml_out( \@specs)});
 
 	my @pairs = map{ spec_to_pairs($_) } @specs;
 
@@ -252,7 +259,7 @@ sub fader_envelope_pairs {
 
 sub spec_to_pairs {
 	my ($from, $to, $type, $op) = @{$_[0]};
-	logit(__LINE__,'Audio::Nama::Fade','debug',"from: $from, to: $to, type: $type");
+	logpkg(__FILE__,__LINE__,'debug',"from: $from, to: $to, type: $type");
 	my $cutpos;
 	my @pairs;
 
@@ -311,7 +318,7 @@ sub remove {
 	
 	my @track_fades = all_fades($fade->track);
 	if ( ! @track_fades ){ 
-		Audio::Nama::remove_effect($track->fader);
+		remove_effect($track->fader);
 		$tn{$fade->track}->set(fader => undef);
 	}
 	else { refresh_fade_controller($track) }
@@ -327,7 +334,7 @@ sub add_fader {
 	
 	if (! $id){	
 		my $first_effect = $track->ops->[0];
-		$id = Audio::Nama::add_effect({
+		$id = add_effect({
 				before 	=> $first_effect, 
 				track	=> $track,
 				type	=> $config->{fader_op}, 
