@@ -197,7 +197,7 @@ sub init_gui {
 				#$text->{term}->tkRunning(0);
 				#$gui->{ew}->destroy;
 				#$gui->{mw}->destroy;
-				#Audio::Nama::command_process('quit');
+				#Audio::Nama::process_command('quit');
 				exit;
 				 });
 	$gui->{palette}->configure(
@@ -229,7 +229,7 @@ $gui->{palette}->AddItems( @color_items);
 			-command => sub { 
 								return if $gui->{_track_name} =~ /^\s*$/;	
 								add_track(remove_spaces($gui->{_track_name}));
-								command_process('stereo');
+								process_command('stereo');
 	});
 
 	my @labels = 
@@ -395,7 +395,7 @@ sub some_user_tracks {
 sub flash_ready {
 
 	my $color = engine_mode_color();
-	logit(__LINE__,__PACKAGE__,'debug', "flash color: $color");
+	logpkg(__FILE__,__LINE__,'debug', "flash color: $color");
 	$ui->length_display(-background => $color);
 	$ui->project_label_configure(-background => $color) unless $mode->{preview};
  	$engine->{events}->{heartbeat} = AE::timer(5, 0, \&reset_engine_mode_color_display);
@@ -461,14 +461,14 @@ sub group_gui {
 				}
 			]);
 			$dummy->grid($gui->{group_label}, $gui->{group_version}, $gui->{group_rw});
-			$ui->global_version_buttons;
+			#$ui->global_version_buttons;
 
 }
 sub global_version_buttons {
 	my $version = $gui->{group_version};
 	$version and map { $_->destroy } $version->children;
 		
-	logit(__LINE__,__PACKAGE__,'debug', "making global version buttons range: " ,
+	logpkg(__FILE__,__LINE__,'debug', "making global version buttons range: " ,
 		join ' ',1..$bn{Main}->last);
 
 			$version->radiobutton( 
@@ -514,7 +514,7 @@ sub track_gui {
 	my $n = shift;
 	return if $ti{$n}->hide;
 	
-	logit(__LINE__,__PACKAGE__,'debug', "found index: $n");
+	logpkg(__FILE__,__LINE__,'debug', "found index: $n");
 	my @rw_items = @_ ? @_ : (
 			[ 'command' => "REC",
 				-foreground => 'red',
@@ -523,7 +523,7 @@ sub track_gui {
 					$ti{$n}->set(rw => "REC");
 					
 					$ui->refresh_track($n);
-					refresh_group();
+					#refresh_group();
 					Audio::Nama::reconfigure_engine();
 			}],
 			[ 'command' => "MON",
@@ -531,7 +531,7 @@ sub track_gui {
 					return if Audio::Nama::eval_iam("engine-status") eq 'running';
 					$ti{$n}->set(rw => "MON");
 					$ui->refresh_track($n);
-					refresh_group();
+					#refresh_group();
 					Audio::Nama::reconfigure_engine();
 			}],
 			[ 'command' => "OFF", 
@@ -539,7 +539,7 @@ sub track_gui {
 					return if Audio::Nama::eval_iam("engine-status") eq 'running';
 					$ti{$n}->set(rw => "OFF");
 					$ui->refresh_track($n);
-					refresh_group();
+					#refresh_group();
 					Audio::Nama::reconfigure_engine();
 			}],
 		);
@@ -631,17 +631,17 @@ sub track_gui {
 
 		my $vol_id = $ti{$n}->vol;
 
-		logit(__LINE__,__PACKAGE__,'debug', "vol cop_id: $vol_id");
+		logpkg(__FILE__,__LINE__,'debug', "vol effect_id: $vol_id");
 		my %p = ( 	parent => \$gui->{track_frame},
 				chain  => $n,
 				type => 'ea',
-				cop_id => $vol_id,
+				effect_id => $vol_id,
 				p_num		=> $p_num,
 				length => 300, 
 				);
 
 
-		 logit(__LINE__,__PACKAGE__,'debug',sub{my %q = %p; delete $q{parent}; print
+		 logpkg(__FILE__,__LINE__,'debug',sub{my %q = %p; delete $q{parent}; print
 		 "=============\n%p\n",yaml_out(\%q)});
 
 		$vol = make_scale ( \%p );
@@ -686,15 +686,15 @@ sub track_gui {
 		
 		my $pan_id = $ti{$n}->pan;
 		
-		logit(__LINE__,__PACKAGE__,'debug', "pan cop_id: $pan_id");
+		logpkg(__FILE__,__LINE__,'debug', "pan effect_id: $pan_id");
 		$p_num = 0;           # first parameter
 		my %q = ( 	parent => \$gui->{track_frame},
 				chain  => $n,
 				type => 'epp',
-				cop_id => $pan_id,
+				effect_id => $pan_id,
 				p_num		=> $p_num,
 				);
-		# logit(__LINE__,__PACKAGE__,'debug',sub{ my %q = %p; delete $q{parent}; print "x=============\n%p\n",yaml_out(\%q) });
+		# logpkg(__FILE__,__LINE__,'debug',sub{ my %q = %p; delete $q{parent}; print "x=============\n%p\n",yaml_out(\%q) });
 		$pan = make_scale ( \%q );
 
 		# Center
@@ -717,7 +717,7 @@ sub track_gui {
 
 	@{ $gui->{tracks}->{$n} }{qw(name version rw ch_r ch_m mute effects)} 
 		= ($name,  $version, $rw, $ch_r, $ch_m, $mute, \$effects);#a ref to the object
-	#logit(__LINE__,__PACKAGE__,'debug', "=============$gui->{tracks}\n",sub{yaml_out($gui->{tracks})});
+	#logpkg(__FILE__,__LINE__,'debug', "=============$gui->{tracks}\n",sub{yaml_out($gui->{tracks})});
 	my $independent_effects_frame 
 		= ${ $gui->{tracks}->{$n}->{effects} }->Frame->pack(-fill => 'x');
 
@@ -735,7 +735,7 @@ sub track_gui {
 	$independent_effects_frame
 		->Label(-text => uc $ti{$n}->name )->pack(-side => 'left');
 
-	#logit(__LINE__,__PACKAGE__,'debug',"Number: $n"),MainLoop if $n == 2;
+	#logpkg(__FILE__,__LINE__,'debug',"Number: $n"),MainLoop if $n == 2;
 	my @tags = qw( EF P1 P2 L1 L2 L3 L4 );
 	my @starts =   ( $fx_cache->{split}->{cop}{a}, 
 					 $fx_cache->{split}->{preset}{a}, 
@@ -822,7 +822,7 @@ sub create_master_and_mix_tracks {
 
 	$ui->track_gui( $tn{Mixdown}->n); 
 
-	$ui->group_gui('Main');
+	#$ui->group_gui('Main');
 }
 
 sub update_version_button {
@@ -844,20 +844,20 @@ sub add_effect_gui {
 		my $ui = shift;
 		my %p 			= %{shift()};
 		my ($n,$code,$id,$parent_id,$parameter) =
-			@p{qw(chain type cop_id parent_id parameter)};
+			@p{qw(chain type effect_id parent_id parameter)};
 		my $i = $fx_cache->{full_label_to_index}->{$code};
 
-		logit(__LINE__,__PACKAGE__,'debug', sub{yaml_out(\%p)});
+		logpkg(__FILE__,__LINE__,'debug', sub{yaml_out(\%p)});
 
-		logit(__LINE__,__PACKAGE__,'debug', "cop_id: $id, parent_id: $parent_id");
-		# $id is determined by cop_add, which will return the
-		# existing cop_id if supplied
+		logpkg(__FILE__,__LINE__,'debug', "effect_id: $id, parent_id: $parent_id");
+		# $id is determined by effect_init, which will return the
+		# existing effect_id if supplied
 
 		# check display format, may be 'scale' 'field' or 'hidden'
 		
 		my $display_type = $fx->{applied}->{$id}->{display}; # individual setting
 		defined $display_type or $display_type = $fx_cache->{registry}->[$i]->{display}; # template
-		logit(__LINE__,__PACKAGE__,'debug', "display type: $display_type");
+		logpkg(__FILE__,__LINE__,'debug', "display type: $display_type");
 
 		return if $display_type eq q(hidden);
 
@@ -880,7 +880,7 @@ sub add_effect_gui {
 		my $parentage = $fx_cache->{registry}->[ $fx_cache->{full_label_to_index}->{ $fx->{applied}->{$parent_id}->{type}} ]
 			->{name};
 		$parentage and $parentage .=  " - ";
-		logit(__LINE__,__PACKAGE__,'debug', "parentage: $parentage");
+		logpkg(__FILE__,__LINE__,'debug', "parentage: $parentage");
 		my $eff = $frame->Menubutton(
 			-text => $parentage. $fx_cache->{registry}->[$i]->{name}, -tearoff => 0,);
 
@@ -896,7 +896,7 @@ sub add_effect_gui {
 
 		for my $p (0..$fx_cache->{registry}->[$i]->{count} - 1 ) {
 		my @items;
-		#logit(__LINE__,__PACKAGE__,'debug', "p_first: $p_first, p_last: $p_last");
+		#logpkg(__FILE__,__LINE__,'debug', "p_first: $p_first, p_last: $p_last");
 		for my $j ($fx_cache->{split}->{ctrl}{a}..$fx_cache->{split}->{ctrl}{z}) {   
 			push @items, 				
 				[ 'command' => $fx_cache->{registry}->[$j]->{name},
@@ -913,11 +913,11 @@ sub add_effect_gui {
 				-menuitems => [@items],
 				-tearoff => 0,
 		);
-			logit(__LINE__,__PACKAGE__,'debug', "parameter name: ",
+			logpkg(__FILE__,__LINE__,'debug', "parameter name: ",
 				$fx_cache->{registry}->[$i]->{params}->[$p]->{name});
 			my $v =  # for argument vector 
 			{	parent => \$frame,
-				cop_id => $id, 
+				effect_id => $id, 
 				p_num  => $p,
 			};
 			push @sliders,make_scale($v);
@@ -960,10 +960,10 @@ sub remove_effect_gui {
 	logsub("&remove_effect_gui");
 	my $id = shift;
 	my $n = $fx->{applied}->{$id}->{chain};
-	logit(__LINE__,__PACKAGE__,'debug', "id: $id, chain: $n");
+	logpkg(__FILE__,__LINE__,'debug', "id: $id, chain: $n");
 
-	logit(__LINE__,__PACKAGE__,'debug', "i have widgets for these ids: ", join " ",keys %{$gui->{fx}});
-	logit(__LINE__,__PACKAGE__,'debug', "preparing to destroy: $id");
+	logpkg(__FILE__,__LINE__,'debug', "i have widgets for these ids: ", join " ",keys %{$gui->{fx}});
+	logpkg(__FILE__,__LINE__,'debug', "preparing to destroy: $id");
 	return unless defined $gui->{fx}->{$id};
 	$gui->{fx}->{$id}->destroy();
 	delete $gui->{fx}->{$id}; 
@@ -973,15 +973,15 @@ sub remove_effect_gui {
 sub effect_button {
 	logsub("&effect_button");
 	my ($n, $label, $start, $end) = @_;
-	logit(__LINE__,__PACKAGE__,'debug', "chain $n label $label start $start end $end");
+	logpkg(__FILE__,__LINE__,'debug', "chain $n label $label start $start end $end");
 	my @items;
 	my $widget;
 	my @indices = ($start..$end);
 	if ($start >= $fx_cache->{split}->{ladspa}{a} and $start <= $fx_cache->{split}->{ladspa}{z}){
 		@indices = ();
 		@indices = @{$fx_cache->{ladspa_sorted}}[$start..$end];
-		logit(__LINE__,__PACKAGE__,'debug', "length sorted indices list: ",scalar @indices );
-	logit(__LINE__,__PACKAGE__,'debug', "Indices: @indices");
+		logpkg(__FILE__,__LINE__,'debug', "length sorted indices list: ",scalar @indices );
+	logpkg(__FILE__,__LINE__,'debug', "Indices: @indices");
 	}
 		
 		for my $j (@indices) { 
@@ -1008,31 +1008,31 @@ sub make_scale {
 	my $ref = shift;
 	my %p = %{$ref};
 # 	%p contains following:
-# 	cop_id   => operator id, to access dynamic effect params in %{$fx->{params}}
+# 	effect_id   => operator id, to access dynamic effect params in %{$fx->{params}}
 # 	parent => parent widget, i.e. the frame
 # 	p_num      => parameter number, starting at 0
 # 	length       => length widget # optional 
-	my $id = $p{cop_id};
+	my $id = $p{effect_id};
 	my $n = $fx->{applied}->{$id}->{chain};
 	my $code = $fx->{applied}->{$id}->{type};
 	my $p  = $p{p_num};
 	my $i  = $fx_cache->{full_label_to_index}->{$code};
 
-	logit(__LINE__,__PACKAGE__,'debug', "id: $id code: $code");
+	logpkg(__FILE__,__LINE__,'debug', "id: $id code: $code");
 	
 
 	# check display format, may be text-field or hidden,
 
-	logit(__LINE__,__PACKAGE__,'debug',"i: $i code: $fx_cache->{registry}->[$i]->{code} display: $fx_cache->{registry}->[$i]->{display}");
+	logpkg(__FILE__,__LINE__,'debug',"i: $i code: $fx_cache->{registry}->[$i]->{code} display: $fx_cache->{registry}->[$i]->{display}");
 	my $display_type = $fx->{applied}->{$id}->{display};
 	defined $display_type or $display_type = $fx_cache->{registry}->[$i]->{display};
-	logit(__LINE__,__PACKAGE__,'debug', "display type: $display_type");
+	logpkg(__FILE__,__LINE__,'debug', "display type: $display_type");
 	return if $display_type eq q(hidden);
 
 
-	logit(__LINE__,__PACKAGE__,'debug', "to: ", $fx_cache->{registry}->[$i]->{params}->[$p]->{end}) ;
-	logit(__LINE__,__PACKAGE__,'debug', "p: $p code: $code");
-	logit(__LINE__,__PACKAGE__,'debug', "is_log_scale: ".is_log_scale($i,$p));
+	logpkg(__FILE__,__LINE__,'debug', "to: ", $fx_cache->{registry}->[$i]->{params}->[$p]->{end}) ;
+	logpkg(__FILE__,__LINE__,'debug', "p: $p code: $code");
+	logpkg(__FILE__,__LINE__,'debug', "is_log_scale: ".is_log_scale($i,$p));
 
 	# set display type to individually specified value if it exists
 	# otherwise to the default for the controller class
@@ -1057,7 +1057,8 @@ sub make_scale {
 			-resolution => resolution($i, $p),
 		  -width => 12,
 		  -length => $p{length} ? $p{length} : 100,
-		  -command => sub { Audio::Nama::effect_update($id, $p, $fx->{params}->{$id}->[$p]) }
+		  -command => sub { Audio::Nama::effect_update($id, $p, $fx->{params}->{$id}->[$p]) },
+			-state => is_read_only($id,$p) ? 'disabled' : 'normal',
 		  );
 
 		# auxiliary field for logarithmic display
@@ -1238,7 +1239,7 @@ sub namaset {
 sub colorchooser { 
 	logsub("&colorchooser");
 	my ($field, $initialcolor) = @_;
-	logit(__LINE__,__PACKAGE__,'debug', "field: $field, initial color: $initialcolor");
+	logpkg(__FILE__,__LINE__,'debug', "field: $field, initial color: $initialcolor");
 	my $new_color = $gui->{mw}->chooseColor(
 							-title => $field,
 							-initialcolor => $initialcolor,
@@ -1391,7 +1392,7 @@ sub refresh_track {
 
 sub refresh {  
 	Audio::Nama::remove_riff_header_stubs();
- 	$ui->refresh_group(); 
+ 	#$ui->refresh_group(); 
 	#map{ $ui->refresh_track($_) } map{$_->n} grep{!  $_->hide} Audio::Nama::Track::all();
 	#map{ $ui->refresh_track($_) } grep{$remove_track_widget{$_} map{$_->n}  Audio::Nama::Track::all();
 	map{ $ui->refresh_track($_) } map{$_->n}  Audio::Nama::Track::all();
