@@ -32,12 +32,29 @@ sub helpline {
 	
 }
 sub helptopic {
-	my $index = shift;
-	$index =~ /^(\d+)$/ and $index = $help->{arr_topic}->[$index];
+	my $user_input = shift;
+
+	# we expect topic number or topic name
+	
+	my ($index, $name);
+	if( $user_input =~ /(\D+)/ ){ 
+		$name = $1;
+	}
+	else { 
+		$index = $user_input;
+		$name = $help->{arr_topic}->[$index];
+	}
+	#system("man","nama") if $index== 15;
+	format_help_topic($index, $name);
+}
+
+sub format_help_topic {
+	my ($index, $name) = @_;
 	my @output;
-	push @output, "\n-- ", ucfirst $index, " --\n\n";
-	push @output, $help->{topic}->{$index}, $/;
-	@output;
+	push @output, "\n-- ", ucfirst $name, " --\n\n";
+	push @output, $help->{topic}->{$name}, $/;
+	push @output, $help->{usage} if $index == 14;
+	@output
 }
 
 sub help { 
@@ -113,11 +130,11 @@ sub help_effect {
 		push @output, grep{ /$id/  } @{$fx_cache->{user_help}};
 	}
 
-	# full help for LADSPA plugins
+	# full help for LADSPA/LV2 plugins
 	
-	elsif ( $id =~ /el:/) {
-		@output = $fx_cache->{ladspa_help}->{$id};
-	} else { 
+	elsif ( $id =~ /el:/  ) { @output = $fx_cache->{ladspa_help}->{$id} }
+	elsif ( $id =~ /elv2:/) { @output = $fx_cache->{lv2_help}->{$id}    }
+	else { 
 		@output = qq("$id" is an Ecasound chain operator.
 Type 'man ecasound' at a shell prompt for details.);
 	}
@@ -171,9 +188,10 @@ sub find_effect {
                     mixdown
                     prompt 
                     diagnostics
-					fades
 					edits
-
+					fades
+					command_line_options
+					man_page
                 ) ;
 
 %{$help->{topic}} = (
@@ -189,14 +207,28 @@ HELP
 
 project => <<PROJECT,
    load_project, load        - load an existing project 
-   project_name, name          - show the current project name
+   project_name, name        - show the current project name
    create_project, create    - create a new project directory tree 
    list_projects, lp         - list all Nama projects
-   get_state, recall, retrieve, restore  - retrieve saved settings
-   save_state, keep, save    - save project settings to disk
-   memoize                   - enable WAV directory cache (default OFF)
-   unmemoize                 - disable WAV directory cache
+   get_state, get            - retrieve named file or tag
+   save_state, keep, save    - save state as file or tag
    exit, quit                - exit program, saving state 
+
+ (Version control)
+
+   save                      - save, commit and tag with <tagname>
+   get                       - checkout tag <tagname> 
+                               or associated branch and load
+   branch, br                - switch to designated branch and load
+   list_branches, lbr        - list branches and tags (without arguments)
+   new_branch, nbr           - create a new branch starting at the current 
+                               commit or a specified commit 
+   tag                       - tag current commit with a name and optional 
+                               message
+   
+   memoize                   - enable WAV directory cache
+   unmemoize                 - disable WAV directory cache
+   
 PROJECT
 
 chain_setup => <<SETUP,
@@ -338,12 +370,11 @@ track => <<TRACK,
    cache_track,   cache,   ct  - store effects-processed track signal as new version
    uncache_track, uncache, unc - select uncached track version, replace effects
 
- - hazardous commands for advanced users
+ - hazardous or destructive commands for advanced users
 
    set_track               - directly set current track parameters
 
    destroy_current_wav     - unlink current track's selected WAV version.
-                             Destructive command! USE WITH CARE!!
 
 TRACK
 
@@ -604,6 +635,10 @@ help is available for the following topics:
 11 Diagnostics
 12 Edits
 13 Fades
+14 Command line options
+15 Man page
+911  All other issues
+
 HELP
 
 1;
\ No newline at end of file
