@@ -41,8 +41,8 @@ our %io_class = qw(
 	null_out				Audio::Nama::IO::to_null
 	soundcard_in 			Audio::Nama::IO::from_soundcard
 	soundcard_out 			Audio::Nama::IO::to_soundcard
-	soundcard_device_in 	Audio::Nama::IO::from_soundcard_device
-	soundcard_device_out 	Audio::Nama::IO::to_soundcard_device
+	soundcard_device_in 	Audio::Nama::IO::from_alsa_soundcard_device
+	soundcard_device_out 	Audio::Nama::IO::to_alsa_soundcard_device
 	wav_in 					Audio::Nama::IO::from_wav
 	wav_out 				Audio::Nama::IO::to_wav
 	loop_source				Audio::Nama::IO::from_loop
@@ -108,24 +108,32 @@ sub new {
 	# join IO objects to graph
 	my $name;
 	try{ $name  = $self->name }
-	catch {  say "name method blew up for this object"  }; 
+	catch {};  # we do nothing
 
 	{ no warnings 'uninitialized';
-	Audio::Nama::logit(__LINE__,"Audio::Nama::IO","debug","I belong to track $name\n",
+	Audio::Nama::logpkg(__FILE__,__LINE__,'debug',"I belong to track $name\n",
 		sub{Dumper($self)} );
 	}
 	
 	if($name){
 		$by_name{$name}->{$direction} = $self;
 	}
-	else {say "DOES NOT HAVE ASSOCIATED TRACK"}
 	$self
 }
 
 # latency stubs
-sub capture_latency { die "capture stub" }
-sub playback_latency { die "playback stub" }
-sub ports { die "ports stub" }
+sub capture_latency {
+	my $self = shift;
+	return unless $self->client;
+	Audio::Nama::jack_port_latency('input', rectified($self->client));
+}
+sub playback_latency {
+	my $self = shift;
+	return unless $self->client;
+	Audio::Nama::jack_port_latency('output', rectified($self->client));
+}
+sub ports {} # no ports by default
+sub client {} # not a JACK client by default
 
 sub ecs_string {
 	my $self = shift;
@@ -278,7 +286,11 @@ sub quote_jack_port {
 	my $port = shift;
 	($port =~ /\s/ and $port !~ /^"/) ? qq("$port") : $port
 }
-
+sub rectified { # client name from number
+	$_[0] !~ /D/ 
+		? 'system' # source_id or send_id matching digit
+		: $_[0]
+}
 
 ### subclass definitions
 
@@ -288,25 +300,25 @@ sub quote_jack_port {
 {
 package Audio::Nama::IO::from_null;
 use Modern::Perl; use vars qw(@ISA); @ISA = 'Audio::Nama::IO';
-sub _device_id { 'null' } # 
+sub _device_id { 'null' }  
 }
 
 {
 package Audio::Nama::IO::to_null;
 use Modern::Perl; use vars qw(@ISA); @ISA = 'Audio::Nama::IO';
-sub _device_id { 'null' }  # underscore for testing
+sub _device_id { 'null' }
 }
 
 {
 package Audio::Nama::IO::from_rtnull;
 use Modern::Perl; use vars qw(@ISA); @ISA = 'Audio::Nama::IO';
-sub _device_id { 'rtnull' } # 
+sub _device_id { 'rtnull' }  
 }
 
 {
 package Audio::Nama::IO::to_rtnull;
 use Modern::Perl; use vars qw(@ISA); @ISA = 'Audio::Nama::IO';
-sub _device_id { 'rtnull' }  # underscore for testing
+sub _device_id { 'rtnull' }  
 }
 
 {
@@ -322,8 +334,8 @@ sub device_id {
 	join(q[,],@modifiers);
 }
 sub ecs_extra { $_[0]->mono_to_stereo}
+sub client { 'system' if $jack->{jackd_running} } # since we share latency value
 }
-
 {
 package Audio::Nama::IO::to_wav;
 use Modern::Perl; use vars qw(@ISA); @ISA = 'Audio::Nama::IO';
@@ -390,19 +402,6 @@ sub ports {
 	Audio::Nama::IO::jack_multi_ports($client,$client_direction,$channel,$self->width, Audio::Nama::try{$self->name} );
 }
 
-sub capture_latency {
-	my $self = shift;
-	my @names = $self->ports();
-	#say "found ports: @names";
-	Audio::Nama::jack_client_node_latency($names[0], 'input');
-}
-sub playback_latency {
-	my $self = shift;
-	my @names = $self->ports();
-	#say "found ports: @names";
-	Audio::Nama::jack_client_node_latency($names[0], 'input');
-}
-
 }
 
 {
@@ -416,6 +415,8 @@ package Audio::Nama::IO::to_jack_port;
 use Modern::Perl; use vars qw(@ISA); @ISA = 'Audio::Nama::IO';
 sub format_template { $config->{devices}->{jack}->{signal_format} }
 sub device_id { 'jack,,'.$_[0]->port_name.'_out' }
+sub ports { "ecasound:".$_[0]->port_name. '_out_1' } # at least this one port
+	# HARDCODED port name
 }
 
 {
@@ -423,12 +424,15 @@ package Audio::Nama::IO::from_jack_port;
 use Modern::Perl; use vars qw(@ISA); @ISA = 'Audio::Nama::IO::to_jack_port';
 sub device_id { 'jack,,'.$_[0]->port_name.'_in' }
 sub ecs_extra { $_[0]->mono_to_stereo }
+sub ports { "ecasound:".$_[0]->port_name. '_in_1' } # at least this one port
+	# HARDCODED port name
 }
 
 {
 package Audio::Nama::IO::to_jack_client;
 use Modern::Perl; use vars qw(@ISA); @ISA = 'Audio::Nama::IO';
 sub device_id { "jack," . Audio::Nama::IO::quote_jack_port($_[0]->send_id); }
+sub client { Audio::Nama::IO::rectified($_[0]->send_id) }
 }
 
 {
@@ -436,10 +440,11 @@ package Audio::Nama::IO::from_jack_client;
 use Modern::Perl; use vars qw(@ISA); @ISA = 'Audio::Nama::IO';
 sub device_id { 'jack,'.  Audio::Nama::IO::quote_jack_port($_[0]->source_id); }
 sub ecs_extra { $_[0]->mono_to_stereo}
+sub client { Audio::Nama::IO::rectified($_[0]->source_id) }
 }
 
 {
-package Audio::Nama::IO::from_soundcard_device;
+package Audio::Nama::IO::from_alsa_soundcard_device;
 use Modern::Perl; use vars qw(@ISA); @ISA = 'Audio::Nama::IO';
 sub ecs_extra { join ' ', $_[0]->rec_route, $_[0]->mono_to_stereo }
 sub device_id { $config->{devices}->{$config->{alsa_capture_device}}->{ecasound_id} }
@@ -459,7 +464,7 @@ sub rec_route {
 }
 }
 {
-package Audio::Nama::IO::to_soundcard_device;
+package Audio::Nama::IO::to_alsa_soundcard_device;
 use Modern::Perl; use vars qw(@ISA); @ISA = 'Audio::Nama::IO';
 sub device_id { $config->{devices}->{$config->{alsa_playback_device}}{ecasound_id} }
 sub ecs_extra {route($_[0]->width,$_[0]->output_channel) }
