@@ -1,8 +1,34 @@
 # ----------- Initialize --------
+#
+#
+#  These routines are executed once on program startup
+#
+#
 
 package Audio::Nama;
 use Modern::Perl; use Carp;
 
+sub apply_test_harness {
+
+	push @ARGV, qw(-f /dev/null), # force to use internal namarc
+
+				qw(-t), # set text mode 
+
+				qw(-d), $Audio::Nama::test_dir,
+				
+				q(-E), # suppress loading Ecasound
+
+				q(-J), # fake jack client data
+
+				q(-T), # don't initialize terminal
+
+				#qw(-L SUB), # logging
+}
+sub apply_ecasound_test_harness {
+	apply_test_harness();
+	@ARGV = grep { $_ ne q(-E) } @ARGV
+}
+
 sub definitions {
 
 	$| = 1;     # flush STDOUT buffer on every write
@@ -10,54 +36,27 @@ sub definitions {
 	$ui eq 'bullwinkle' or die "no \$ui, bullwinkle";
 
 	
-@config_vars = qw(
-	%devices
-	$alsa_playback_device
-	$alsa_capture_device	
-	$soundcard_channels
-	%abbreviations
-	$mix_to_disk_format
-	$raw_to_disk_format
-	$cache_to_disk_format
-	$mixer_out_format
-	$ecasound_tcp_port
-	$ecasound_globals_general
-	$ecasound_globals_realtime
-	$ecasound_globals_nonrealtime
-	$ecasound_buffersize_realtime
-	$ecasound_buffersize_nonrealtime
-	$project_root 	
-	$use_group_numbering
-	$press_space_to_start_transport
-	$execute_on_project_load
-	$initial_user_mode
-	$midish_enable
-	$quietly_remove_tracks
-	$use_jack_plumbing
-	$jack_seek_delay
-	$use_monitor_version_for_mixdown 
-	$volume_control_operator
-	$eager_mode
-	$serialize_formats
-	$use_git
-	$beep_command
-	$eq 
-	$low_pass
-	$mid_pass
-	$high_pass
-	$compressor
-	$spatialiser
-	$limiter
-);
+
+
+
+
+
+
+
+
+					
+
+
+
 @global_effect_chain_vars  = qw(@global_effect_chain_data $Audio::Nama::EffectChain::n );
-@new_persistent_vars = qw(
-	$project->{save_file_version_number}
-	$project->{config}
-	$fx->{id_counter}
-	$fx->{applied}
-	$fx->{params}
-	$fx->{params_log}}
-	$gui->{_seek_unit}
+
+
+
+
+@persistent_vars = qw(
+
+
+
 	@tracks_data
 	@bus_data
 	@groups_data
@@ -65,39 +64,42 @@ sub definitions {
 	@fade_data
 	@edit_data
 	@inserts_data
+
+	$project->{save_file_version_number}
+	
+	$fx->{applied}
+	$fx->{params}
+	$fx->{params_log}
+
+);
+
+
+
+
+
+@persistent_untracked_vars = qw(
+
+	$project->{save_file_version_number}
+	$project->{timebase}
+	$project->{cache_map}
+	$project->{undo_buffer}
+	$project->{track_version_comments}
+	$project->{track_comments}
+	$project->{bunch}
 	@project_effect_chain_data
+	$fx->{id_counter}
 	$setup->{loop_endpoints}
 	$mode->{loop_enable}
-	$setup->{audio_length}
-	$project->{bunch}
-	$text->{command_history}
 	$mode->{mastering}
+	$mode->{preview}
+	$mode->{midish_terminal}
+	$mode->{midish_transport_sync}
+	$gui->{_seek_unit}
+	$text->{command_history}
 	$this_track_name
 	$this_op
 );
-@persistent_vars = qw(
-	$saved_version 	
-	$cop_id 		
-	%cops			
-	%copp			
-	%copp_exp      	
-	$unit			
-	@tracks_data
-	@bus_data
-	@groups_data
-	@marks_data
-	@fade_data
-	@edit_data
-	@inserts_data
-	@loop_endpoints 
-	$loop_enable 	
-	$length			
-	%bunch			
-	@command_history
-	$mastering_mode
-	$this_track_name 
-	$this_op      	
-);
+
 
 
 	$text->{wrap} = new Text::Format {
@@ -110,11 +112,12 @@ sub definitions {
 	####### Initialize singletons #######
 
 	# Some of these "singletons" (imported by 'use Globals')
-	# are just hashes, some have object behavior.
-	#
-	# $file belongs to class Audio::Nama::File, and uses
+	# are just hashes, some have object behavior as
+	# the sole instance of their class.
+	
+	# for example, $file belongs to class Audio::Nama::File, and uses
 	# AUTOLOAD to generate methods to provide full path
-	# to various system files, for example $file->state_store
+	# to various system files, such as $file->state_store
 
 	{
 	package Audio::Nama::File;
@@ -133,36 +136,58 @@ sub definitions {
 			my $path = Audio::Nama::join_path($dir_sub->(), $filename);
 			$path;
 		}
+		sub DESTROY {}
 		1;
 	}
 	$file = bless 
 	{
 		effects_cache 			=> ['.effects_cache', 		\&project_root],
 		gui_palette 			=> ['palette',        		\&project_root],
-		state_store 			=> ['State',          		\&project_dir ],
+		state_store 			=> ['State',      			\&project_dir ],
 		git_state_store 		=> ['State.json',      		\&project_dir ],
+		untracked_state_store => ['Aux',					\&project_dir ],
 		effect_profile 			=> ['effect_profiles',		\&project_root],
 		chain_setup 			=> ['Setup.ecs',      		\&project_dir ],
 		user_customization 		=> ['custom.pl',      		\&project_root],
 		project_effect_chains 	=> ['project_effect_chains',\&project_dir ],
-		project_config			=> ['project_config', 		\&project_dir ],
 		global_effect_chains  	=> ['global_effect_chains', \&project_root],
 		old_effect_chains  		=> ['effect_chains', 		\&project_root],
 		_logfile				=> ['nama.log',				\&project_root],
 
-	}, 'Audio::Nama::File';
 
+	}, 'Audio::Nama::File';
 
 	$gui->{_save_id} = "State";
 	$gui->{_seek_unit} = 1;
 	$gui->{marks} = {};
 
+
+# 
+# use this section to specify 
+# defaults for config variables 
+#
+# These are initial, lowest priority defaults
+# defaults for Nama config. Some variables
+# may be overwritten during subsequent read_config's
+#
+# config variable sources are prioritized as follows
+
+	#
+	#		+   command line argument -f /path/to/namarc 
+	#		+   project specific namarc  # currently disabled
+	#		+	user namarc (usually ~/.namarc)
+	#		+	internal namarc
+	#		+	internal initialization
+
+
 	$config = bless {
 		root_dir 						=> join_path( $ENV{HOME}, "nama"),
 		soundcard_channels 				=> 10,
 		memoize 						=> 1,
 		use_pager 						=> 1,
 		use_placeholders 				=> 1,
+		use_git							=> 1,
+		autosave						=> 0,
 		volume_control_operator 		=> 'ea', # default to linear scale
 		sync_mixdown_and_monitor_version_numbers => 1, # not implemented yet
 		engine_fade_length_on_start_stop => 0.3, # when starting/stopping transport
@@ -180,26 +205,34 @@ sub definitions {
 		fade_resolution 				=> 20, # steps per second
 		no_fade_mute_delay				=> 0.03,
 		enforce_channel_bounds			=> 1,
-		# for save_system_state()
-		serialize_formats               => 'json',
+
+
+		serialize_formats               => 'json',		# for save_system_state()
+
+		engine_globals_common			=> "-z:mixmode,sum",
+		engine_globals_realtime			=> "-z:db,100000 -z:nointbuf",
+		engine_globals_nonrealtime		=> "-z:nodb -z:intbuf",
+		engine_buffersize_realtime		=> 256, 
+		engine_buffersize_nonrealtime	=> 1024,
+		latency_op						=> 'el:delay_n',
+		latency_op_init					=> [0,0],
+		latency_op_set					=> sub
+			{
+				my $id = shift;
+				my $delay = shift();
+				modify_effect($id,2,undef,$delay)
+			},
 	}, 'Audio::Nama::Config';
 
+
 	{ package Audio::Nama::Config;
 	use Carp;
 	use Audio::Nama::Globals qw(:singletons);
 	use Modern::Perl;
 	our @ISA = 'Audio::Nama::Object'; #  for ->dump and ->as_hash methods
 
-	# special handling of serialize formats to store them as 
-	# space separate tags, must duplicate AUTOLOAD checking
+	sub serialize_formats { split " ", $_[0]->{serialize_formats} }
 
-	sub serialize_formats { 
-			split " ", 
-			(
-				$project->{config}->{serialize_formats} 
-			  || $_[0]->{serialize_formats}
-			)
-	}
 	sub hardware_latency {
 		no warnings 'uninitialized';
 		$config->{devices}->{$config->{alsa_capture_device}}{hardware_latency} || 0
@@ -217,7 +250,7 @@ sub definitions {
 
 	$mode->{mastering} = 0;
 
-	init_memoize() if $config->{memoize};
+	init_wav_memoize() if $config->{memoize};
 
 }
 
@@ -241,7 +274,7 @@ BANNER
 	if ( ! $config->{opts}->{t} and Audio::Nama::Graphical::initialize_tk() ){ 
 		$ui = Audio::Nama::Graphical->new();
 	} else {
-		say "Unable to load perl Tk module. Starting in console mode." if $config->{opts}->{g};
+		pager3( "Unable to load perl Tk module. Starting in console mode.") if $config->{opts}->{g};
 		$ui = Audio::Nama::Text->new();
 		can_load( modules =>{ Event => undef})
 			or die "Perl Module 'Event' not found. Please install it and try again. Stopping.";
@@ -259,20 +292,19 @@ BANNER
 
 	$project->{name} = shift @ARGV;
 	{no warnings 'uninitialized';
-	logit(__LINE__,'Audio::Nama::Config','debug',"project name: $project->{name}");
+	logpkg(__FILE__,__LINE__,'debug',"project name: $project->{name}");
 	}
 
-	logit(__LINE__,'Audio::Nama::Config','debug',
-		sub{"Command line options\n".  yaml_out($config->{opts})});
+	logpkg(__FILE__,__LINE__,'debug', sub{"Command line options\n".  yaml_out($config->{opts})});
 
 	read_config(global_config());  # from .namarc if we have one
 	
-	logit(__LINE__,'Audio::Nama::Config','debug',sub{"Config data\n".Dumper $config});
+	logpkg(__FILE__,__LINE__,'debug',sub{"Config data\n".Dumper $config});
 	
 
 	start_ecasound();
 
-	logit(__LINE__,'Audio::Nama::Config','debug',"reading config file");
+	logpkg(__FILE__,__LINE__,'debug',"reading config file");
 	if ($config->{opts}->{d}){
 		print "project_root $config->{opts}->{d} specified on command line\n";
 		$config->{root_dir} = $config->{opts}->{d};
@@ -322,24 +354,31 @@ BANNER
 	and process_is_running('jack.plumbing')
 	){
 
-		say "\nJack.plumbing daemon detected!";
-		print "\nAttempting to stop it (will restart as needed)... ";
+		pager3(<<PLUMB);
+Jack.plumbing daemon detected!
+
+Attempting to stop it...  
+
+(This may break other software that depends in jack.plumbing.)
+
+Nama will restart it as needed for Nama's use only.
+PLUMB
 
 		kill_jack_plumbing();
 		sleeper(0.2);
 		if( process_is_running('jack.plumbing') )
 		{
-		say qq(\n\nUnable to stop jack.plumbing daemon.
+		throw(q(Unable to stop jack.plumbing daemon.
 
 Please do one of the following, then restart Nama:
 
  - kill the jack.plumbing daemon ("killall jack.plumbing")
  - set "use_jack_plumbing: 0" in .namarc
 
-Exiting.);
+....Exiting.) );
 exit;
 		}
-		else { say "Stopped." }
+		else { pager3("Stopped.") }
 	}
 		
 	start_midish() if $config->{use_midish};
@@ -357,34 +396,43 @@ exit;
 	print "\nproject_name: $project->{name}\n";
 	
 	load_project( name => $project->{name}, create => $config->{opts}->{c}) ;
-	restore_effect_chains();
 	1;	
 }
 sub start_ecasound {
  	my @existing_pids = split " ", qx(pgrep ecasound);
 	select_ecasound_interface();
+	Audio::Nama::Effects::import_engine_subs();
 	sleeper(0.2);
 	@{$engine->{pids}} = grep{ 	my $pid = $_; 
 							! grep{ $pid == $_ } @existing_pids
 						 }	split " ", qx(pgrep ecasound);
 }
 sub select_ecasound_interface {
-	return if $config->{opts}->{E} or $config->{opts}->{A};
-	if ( can_load( modules => { 'Audio::Ecasound' => undef } )
-			and ! $config->{opts}->{n} ){ 
-		say "\nUsing Ecasound via Audio::Ecasound (libecasoundc).";
-		{ no warnings qw(redefine);
-		*eval_iam = \&eval_iam_libecasoundc; }
-		$engine->{ecasound} = Audio::Ecasound->new();
-	} else { 
+	pager3('Not initializing engine: options E or A are set.'),
+			return if $config->{opts}->{E} or $config->{opts}->{A};
 
-		no warnings qw(redefine);
-		launch_ecasound_server($config->{engine_tcp_port});
-		init_ecasound_socket($config->{engine_tcp_port}); 
-		*eval_iam = \&eval_iam_neteci;
-	}
+	# Net-ECI if requested by option, or as fallback 
+	
+	start_ecasound_net_eci(), return if $config->{opts}->{n}
+		or !  can_load( modules => { 'Audio::Ecasound' => undef });
+
+	start_ecasound_libecasoundc();
+}
+
+sub start_ecasound_libecasoundc {
+	pager3("Using Ecasound via Audio::Ecasound (libecasoundc)");
+	no warnings qw(redefine);
+	*eval_iam = \&eval_iam_libecasoundc;
+	$engine->{ecasound} = Audio::Ecasound->new();
 }
 	
+sub start_ecasound_net_eci {
+	pager3("Using Ecasound via Net-ECI"); 
+	no warnings qw(redefine);
+	launch_ecasound_server($config->{engine_tcp_port});
+	init_ecasound_socket($config->{engine_tcp_port}); 
+	*eval_iam = \&eval_iam_neteci;
+}
 
 
 sub choose_sleep_routine {
@@ -402,11 +450,6 @@ sub select_sleep {
    select( undef, undef, undef, $seconds );
 }
 
-sub toggle_transport {
-	if (engine_running()){ stop_transport() } 
-	else { start_transport() }
-}
-	
 {
 my $default_port = 2868; # Ecasound's default
 sub launch_ecasound_server {
@@ -422,11 +465,11 @@ sub launch_ecasound_server {
 	my $command = "ecasound -K -C --server --server-tcp-port=$port";
 	my $redirect = ">/dev/null &";
 	my $ps = qx(ps ax);
-	say("Using existing Ecasound server"), return 
+	pager3("Using existing Ecasound server"), return 
 		if  $ps =~ /ecasound/
 		and $ps =~ /--server/
 		and ($ps =~ /tcp-port=$port/ or $port == $default_port);
-	say "Starting Ecasound server";
+	pager3("Starting Ecasound server");
  	system("$command $redirect") == 0 or carp "system $command failed: $?\n";
 	sleep 1;
 }
@@ -434,7 +477,7 @@ sub launch_ecasound_server {
 
 sub init_ecasound_socket {
 	my $port = shift // $default_port;
-	say "Creating socket on port $port.";
+	pager3("Creating socket on port $port.");
 	$engine->{socket} = new IO::Socket::INET (
 		PeerAddr => 'localhost', 
 		PeerPort => $port, 
@@ -531,6 +574,9 @@ sub munge_category {
 }
 
 }
-	
+sub start_logging { 
+	$config->{want_logging} = initialize_logger($config->{opts}->{L})
+}
+
 1;
 __END__
\ No newline at end of file
