@@ -5,8 +5,9 @@ use Carp;
 no warnings qw(uninitialized redefine);
 our $VERSION = 0.1;
 use vars qw(%by_index);
+use Audio::Nama::Log qw(logpkg);
+use Audio::Nama::Log qw(logpkg);
 use Audio::Nama::Globals qw($jack $setup $config);
-use Audio::Nama::Log qw(logit);
 use Audio::Nama::Object qw(
 	insert_type 
 	n			
@@ -78,6 +79,7 @@ sub new {
 				rw => 'REC');
 
 	map{ Audio::Nama::remove_effect($_)} $wet->vol, $wet->pan, $dry->vol, $dry->pan;
+	map{ my $track = $_;  map{ delete $track->{$_} } qw(vol pan) } $wet, $dry;
 
 	$self->{dry_vol} = Audio::Nama::add_effect({
 		track  => $dry, 
@@ -109,6 +111,7 @@ sub remove {
 #
 sub add_insert {
 	my ($track, $type, $send_id, $return_id) = @_;
+	local $Audio::Nama::this_track;
 	# $type : prefader_insert | postfader_insert
 	say "\n",$track->name , ": adding $type\n";
 	my $name = $track->name;
@@ -166,9 +169,9 @@ sub is_local_effects_host { ! $_[0]->send_id }
 sub set_wetness {
 	my ($self, $p) = @_;
 	$self->{wetness} = $p;
-	Audio::Nama::modify_effect($self->wet_vol, 0, undef, $p);
+	Audio::Nama::modify_effect($self->wet_vol, 1, undef, $p);
 	Audio::Nama::sleeper(0.1);
-	Audio::Nama::modify_effect($self->dry_vol, 0, undef, 100 - $p);
+	Audio::Nama::modify_effect($self->dry_vol, 1, undef, 100 - $p);
 }
 
 
@@ -262,7 +265,7 @@ sub latency {
 package Audio::Nama::PostFaderInsert;
 use Modern::Perl; use Carp; our @ISA = qw(Audio::Nama::Insert);
 use Audio::Nama::Util qw(input_node output_node dest_type);
-use Audio::Nama::Log qw(logit);
+use Audio::Nama::Log qw(logpkg);
 sub add_paths {
 
 	# Since this routine will be called after expand_graph, 
@@ -271,12 +274,12 @@ sub add_paths {
 	
 	my ($self, $g, $name) = @_;
 	no warnings qw(uninitialized);
-	logit(__LINE__,'Audio::Nama::Insert','debug', "add_insert for track: $name");
+	Audio::Nama::logpkg(__FILE__,__LINE__,'debug', "add_insert for track: $name");
 
 	my $t = $Audio::Nama::tn{$name}; 
 
 
-	logit(__LINE__,'Audio::Nama::Insert','debug', "insert structure: ", sub{$self->dump});
+	Audio::Nama::logpkg(__FILE__,__LINE__,'debug', "insert structure: ", sub{$self->dump});
 
 	my ($successor) = $g->successors($name);
 
@@ -288,7 +291,7 @@ sub add_paths {
 	my $wet = $Audio::Nama::tn{$self->wet_name};
 	my $dry = $Audio::Nama::tn{$self->dry_name};
 
-	logit(__LINE__,'Audio::Nama::Insert','debug', "found wet: ", $wet->name, " dry: ",$dry->name);
+	Audio::Nama::logpkg(__FILE__,__LINE__,'debug', "found wet: ", $wet->name, " dry: ",$dry->name);
 
 	# if no insert target, our insert will 
 	# a parallel effects host with wet/dry dry branches
@@ -314,7 +317,7 @@ sub add_paths {
 		# wet send path (no extra track): track -> loop -> output
 
 		my @edge = ($loop, output_node($self->{send_type}));
-		logit(__LINE__,'Audio::Nama::Insert','debug', "edge: @edge");
+		Audio::Nama::logpkg(__FILE__,__LINE__,'debug', "edge: @edge");
 		$g->add_path( $name, @edge);
 		$g->set_vertex_attributes($loop, {n => $t->n});
 		$g->set_edge_attributes(@edge, { 
@@ -345,7 +348,7 @@ sub add_paths {
 package Audio::Nama::PreFaderInsert;
 use Modern::Perl; use Carp; our @ISA = qw(Audio::Nama::Insert);
 use Audio::Nama::Util qw(input_node output_node dest_type);
-use Audio::Nama::Log qw(logit);
+use Audio::Nama::Log qw(logpkg);
 sub add_paths {
 
 # --- predecessor --+-- wet-send    wet-return ---+-- insert_pre -- track
@@ -355,12 +358,12 @@ sub add_paths {
 
 	my ($self, $g, $name) = @_;
 	no warnings qw(uninitialized);
-	logit(__LINE__,'Audio::Nama::Insert','debug', "add_insert for track: $name");
+	Audio::Nama::logpkg(__FILE__,__LINE__,'debug', "add_insert for track: $name");
 
 	my $t = $Audio::Nama::tn{$name}; 
 
 
-	logit(__LINE__,'Audio::Nama::Insert','debug', "insert structure:", sub{$self->dump});
+	Audio::Nama::logpkg(__FILE__,__LINE__,'debug', "insert structure:", sub{$self->dump});
 
 		my ($predecessor) = $g->predecessors($name);
 		$g->delete_edge($predecessor, $name);
@@ -368,13 +371,13 @@ sub add_paths {
 		my $wet = $Audio::Nama::tn{$self->wet_name};
 		my $dry = $Audio::Nama::tn{$self->dry_name};
 
-		logit(__LINE__,'Audio::Nama::Insert','debug', "found wet: ", $wet->name, " dry: ",$dry->name);
+		Audio::Nama::logpkg(__FILE__,__LINE__,'debug', "found wet: ", $wet->name, " dry: ",$dry->name);
 
 
 		#pre:  wet send path (no track): predecessor -> output
 
 		my @edge = ($predecessor, output_node($self->{send_type}));
-		logit(__LINE__,'Audio::Nama::Insert','debug', "edge: @edge");
+		Audio::Nama::logpkg(__FILE__,__LINE__,'debug', "edge: @edge");
 		$g->add_path(@edge);
 		$g->set_edge_attributes(@edge, { 
 			send_id => $self->{send_id},
