@@ -51,14 +51,6 @@ sub initialize_project_data {
 		-background => 'lightyellow',
 		); 
 
-	# effect variables - no object code (yet)
-	
-	$fx->{id_counter} = "A"; # autoincrement counter
-	%{$fx->{applied}}	= ();  # effect and controller objects (hashes)
-	%{$fx->{params}}   = ();  # chain operator parameters
-	               # indexed by {$id}->[$param_no]
-	               # zero-based {AB}->[0] (parameter 1)
-
 	$gui->{tracks} = {};
 	$gui->{fx} = {};
 
@@ -72,10 +64,7 @@ sub initialize_project_data {
 							Audio::Nama::Track
 							Audio::Nama::Insert
 							);
-	
-	# volume settings
-	
-	$fx->{muted} = [];
+	initialize_effects_data();
 
 	# $is_armed = 0;
 	
@@ -83,6 +72,10 @@ sub initialize_project_data {
 	$mode->{preview} = $config->{initial_mode};
 	$mode->{mastering} = 0;
 	$project->{save_file_version_number} = 0; 
+	$project->{track_comments} = {};
+	$project->{track_version_comments} = {};
+	$project->{cache_map} = {};
+	$project->{undo_buffer} = [];
 	
 	$project->{bunch} = {};	
 	
@@ -98,27 +91,50 @@ sub initialize_project_data {
 	$mode->{preview} = 0;
 
 	Audio::Nama::ChainSetup::initialize();
+
 }
+sub initialize_effects_data {
+
+	# effect variables - no object code (yet)
+	
+	$fx->{id_counter} = "A"; # autoincrement counter
+	$fx->{applied}	= {};  # effect and controller objects (hashes)
+	$fx->{params}   = {};  # chain operator parameters
+	               # indexed by {$id}->[$param_no]
+	               # zero-based {AB}->[0] (parameter 1)
+
+	# volume settings
+	
+	$fx->{muted} = [];
+
+}
+
+	
+
 sub load_project {
 	logsub("&load_project");
-	my %h = @_;
-	logit(__LINE__,'Audio::Nama::Project','debug', sub{yaml_out \%h});
-	print("no project name.. doing nothing.\n"),return 
-		unless $h{name} or $project->{name};
-	$project->{name} = $h{name} if $h{name};
+	my %args = @_;
+	logpkg(__FILE__,__LINE__,'debug', sub{yaml_out \%args});
+	throw("no project name.. doing nothing."),return 
+		unless $args{name} or $project->{name};
 
-	if ( ! -d join_path( project_root(), $project->{name}) ){
-		if ( $h{create} ){
-			map{create_dir($_)} &project_dir, &this_wav_dir ;
-		} else { 
-			print qq(
-Project "$project->{name}" does not exist. 
-Loading project "untitled".
-);
+	$project->{name} = $args{name} if $args{name};
+
+	if ( ! -d project_dir() )
+	{ 	
+		if ( $args{create} )
+		{ 
+			map{create_dir($_)} project_dir(), this_wav_dir() ;
+		}
+		else 
+		{ Audio::Nama::pager3(
+			qq(Project "$project->{name}" does not exist.\n Loading project "untitled".)
+			);
 			load_project( qw{name untitled create 1} );
 			return;
-		}
-	} 
+		}	
+	}
+
 	# we used to check each project dir for customized .namarc
 	# read_config( global_config() ); 
 	
@@ -126,19 +142,25 @@ Loading project "untitled".
 	initialize_project_data();
 	remove_riff_header_stubs(); 
 	cache_wav_info();
-	rememoize();
-
-	# initialize git repository if necessary
+	restart_wav_memoize();
 	
-	Git::Repository->run( init => project_dir())
-		if $config->{use_git} and ! -d join_path( project_dir(). '.git');
 
-	# load repository
+	if( $config->{use_git} ){
+		my $initializing_repo;
+		Git::Repository->run( init => project_dir()), $initializing_repo++
+			unless -d join_path( project_dir().  '.git');
+		$project->{repo} = Git::Repository->new( work_tree => project_dir() );
+		write_file($file->git_state_store, "{}\n"), $initializing_repo++
+			if ! -e $file->git_state_store and ! $project->{repo}->run( 'branch' );
+
+		if ($initializing_repo){
+			$project->{repo}->run( add => $file->git_state_store );
+			$project->{repo}->run( commit => '--quiet', '--message', "initial commit");
+		}
+	}
+
+	restore_state($args{settings}) unless $config->{opts}->{M} ;
 
-	$project->{repo} = Git::Repository->new( work_tree => project_dir() )
-		if $config->{use_git};
-	
-	restore_state( $h{settings} ) unless $config->{opts}->{M} ;
 	if (! $tn{Master}){
 
 		Audio::Nama::SimpleTrack->new( 
@@ -160,6 +182,7 @@ Loading project "untitled".
 			source_type => undef,
 			source_id => undef); 
 
+
 		#remove_effect($mixdown->vol);
 		#remove_effect($mixdown->pan);
 	}
@@ -167,26 +190,35 @@ Loading project "untitled".
 
 	$config->{opts}->{M} = 0; # enable 
 	
-	# $h{nodig} allow skip for convert_project_format
-	dig_ruins() unless (scalar @Audio::Nama::Track::all > 2 ) or $h{nodig};
+	# $args{nodig} allow skip for convert_project_format
+	dig_ruins() unless (scalar @Audio::Nama::Track::all > 2 ) or $args{nodig};
 
 	# possible null if Text mode
 	
-	$ui->global_version_buttons(); 
-	$ui->refresh_group;
+	#$ui->global_version_buttons(); 
+	#$ui->refresh_group;
 
-	logit(__LINE__,'Audio::Nama::Project','debug', "project_root: ", project_root());
-	logit(__LINE__,'Audio::Nama::Project','debug', "this_wav_dir: ", this_wav_dir());
-	logit(__LINE__,'Audio::Nama::Project','debug', "project_dir: ", project_dir());
+	logpkg(__FILE__,__LINE__,'debug', "project_root: ", project_root());
+	logpkg(__FILE__,__LINE__,'debug', "this_wav_dir: ", this_wav_dir());
+	logpkg(__FILE__,__LINE__,'debug', "project_dir: ", project_dir());
 
  1;
 }	
+sub restore_state {
+		my $name = shift;
+
+		if( ! $name  or $name =~ /.json$/ or !  $config->{use_git})
+		{
+			restore_state_from_file($name)
+		}
+		else { restore_state_from_vcs($name)  }
+}
 
 sub dig_ruins { # only if there are no tracks 
 	
 	logsub("&dig_ruins");
 	return if Audio::Nama::Track::user();
-	logit(__LINE__,'Audio::Nama::Project','debug', "looking for WAV files");
+	logpkg(__FILE__,__LINE__,'debug', "looking for WAV files");
 
 	# look for wave files
 		
@@ -197,14 +229,14 @@ sub dig_ruins { # only if there are no tracks
 	
 	my @wavs = grep{s/(_\d+)?\.wav//i} readdir $wav;
 
-	closedir $wav;
+	closedir $wav if $wav;
 
 	my %wavs;
 	
 	map{ $wavs{$_}++ } @wavs;
 	@wavs = keys %wavs;
 
-	logit(__LINE__,'Audio::Nama::Project','debug', "tracks found: @wavs");
+	logpkg(__FILE__,__LINE__,'debug', "tracks found: @wavs");
  
 	$ui->create_master_and_mix_tracks();
 
@@ -220,14 +252,15 @@ sub remove_riff_header_stubs {
 	logsub("&remove_riff_header_stubs");
 	
 
-	logit(__LINE__,'Audio::Nama::Project','debug', "this wav dir: ", this_wav_dir());
+	logpkg(__FILE__,__LINE__,'debug', "this wav dir: ", this_wav_dir());
 	return unless this_wav_dir();
          my @wavs = File::Find::Rule ->name( qr/\.wav$/i )
                                         ->file()
                                         ->size(44)
                                         ->extras( { follow => 1} )
-                                     ->in( this_wav_dir() );
-    logit(__LINE__,'Audio::Nama::Project','debug', join $/, @wavs);
+                                     	->in( this_wav_dir() )
+									if -d this_wav_dir();
+    logpkg(__FILE__,__LINE__,'debug', join $/, @wavs);
 
 	map { unlink $_ } @wavs; 
 }
@@ -280,7 +313,7 @@ sub new_project_template {
 
 	# skip if project is empty
 
-	say("No user tracks found, aborting.\n",
+	throw("No user tracks found, aborting.\n",
 		"Cannot create template from an empty project."), 
 		return if scalar @tracks < 3;
 
@@ -353,7 +386,7 @@ sub use_project_template {
 
 	# skip if project isn't empty
 
-	say("User tracks found, aborting. Use templates in an empty project."), 
+	throw("User tracks found, aborting. Use templates in an empty project."), 
 		return if scalar @tracks > 2;
 
 	# load template
@@ -371,7 +404,7 @@ sub list_project_templates {
 }
 sub remove_project_template {
 	map{my $name = $_; 
-		say "$name: removing template";
+		pager2("$name: removing template");
 		$name .= ".yml" unless $name =~ /\.yml$/;
 		unlink join_path( project_root(), "templates", $name);
 	} @_;
